@@ -1,4 +1,4 @@
-// $Id: Timeval.java,v 1.1 2001/06/01 06:25:30 pcharles Exp $
+// $Id: Timeval.java,v 1.2 2003/06/24 23:10:07 pcharles Exp $
 
 /***************************************************************************
  * Copyright (C) 2001, Patrick Charles and Jonas Lehmann                   *
@@ -8,6 +8,7 @@
 package net.sourceforge.jpcap.util;
 
 import java.util.Date;
+import java.io.Serializable;
 
 
 /**
@@ -16,11 +17,11 @@ import java.util.Date;
  * Container for java equivalent of c's struct timeval.
  *
  * @author Patrick Charles and Jonas Lehmann
- * @version $Revision: 1.1 $
+ * @version $Revision: 1.2 $
  * @lastModifiedBy $Author: pcharles $
- * @lastModifiedAt $Date: 2001/06/01 06:25:30 $
+ * @lastModifiedAt $Date: 2003/06/24 23:10:07 $
  */
-public class Timeval
+public class Timeval implements Serializable
 {
   public Timeval(long seconds, int microseconds) {
     this.seconds = seconds;
@@ -48,5 +49,5 @@ public class Timeval
   int microseconds;
 
   private String _rcsid = 
-  "$Id: Timeval.java,v 1.1 2001/06/01 06:25:30 pcharles Exp $";
+  "$Id: Timeval.java,v 1.2 2003/06/24 23:10:07 pcharles Exp $";
 }
